==> google_applovin_unity_ads-1.1.6.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/native_ad/AdMobNative.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads.native_ad

import android.app.Activity
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin
import com.btcpiyush.ads.google_applovin_unity_ads.api.AppSettings
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

data class AdMobNative (
    private val flutterPluginBinding: FlutterPlugin.FlutterPluginBinding,
    private val act: Activity,
    private val it: AppSettings
        ) :
    MethodChannel.MethodCallHandler {

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        when (call.method) {
            GoogleApplovinUnityAdsPlugin.METHOD_LOAD_NATIVE_ADS -> {
                val id = call.argument<String>("id")
                loadNativeAd(id)
            }

            GoogleApplovinUnityAdsPlugin.METHOD_DISPOSE_NATIVE_ADS -> {
                val id = call.argument<String>("id")
                destroyNativeAd(id)
            }

        }
    }


    private fun loadNativeAd(call_id: String?) {

        if (it.googleAds?.isNativeAds == true ||
            it.appLovin?.isNativeAds == true ||
            it.facebookAds?.isNativeAds == true
        ) {
                if (call_id != null) {
                    if (flutterPluginBinding.binaryMessenger != null) {
                        NativeAdControllerManager.createController(
                            GoogleApplovinUnityAdsPlugin.appLovinSDK,
                            call_id,
                            flutterPluginBinding.binaryMessenger,
                            act
                        )
                    }
                }
            }

    }


    private fun destroyNativeAd(call_id: String?) {
        if (call_id != null) {
            NativeAdControllerManager.removeController(call_id)
        }
    }


}

==> google_applovin_unity_ads-1.1.7.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/native_ad/AdMobNative.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads.native_ad

import android.app.Activity
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin
import com.btcpiyush.ads.google_applovin_unity_ads.api.AppSettings
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

data class AdMobNative (
    private val flutterPluginBinding: FlutterPlugin.FlutterPluginBinding,
    private val act: Activity,
    private val it: AppSettings
        ) :
    MethodChannel.MethodCallHandler {

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        when (call.method) {
            GoogleApplovinUnityAdsPlugin.METHOD_LOAD_NATIVE_ADS -> {
                val id = call.argument<String>("id")
                loadNativeAd(id)
            }

            GoogleApplovinUnityAdsPlugin.METHOD_DISPOSE_NATIVE_ADS -> {
                val id = call.argument<String>("id")
                destroyNativeAd(id)
            }
        }
    }


    private fun loadNativeAd(call_id: String?) {

        if (it.googleAds?.isNativeAds == true ||
            it.appLovin?.isNativeAds == true ||
            it.facebookAds?.isNativeAds == true ||
            it.customAds?.isNativeAds == true
        ) {
                if (call_id != null) {
                    if (flutterPluginBinding.binaryMessenger != null) {
                        NativeAdControllerManager.createController(
                            GoogleApplovinUnityAdsPlugin.appLovinSDK,
                            call_id,
                            flutterPluginBinding.binaryMessenger,
                            act
                        )
                    }
                }
            }

    }


    private fun destroyNativeAd(call_id: String?) {
        if (call_id != null) {
            NativeAdControllerManager.removeController(call_id)
        }
    }


}
